@@ -26,8 +26,9 @@ licence="""
 """
 
 import sys, os
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt5.QtCore import *
+from PyQt5.QtGui import *
+from PyQt5.QtWidgets import *
 from glob import glob
 from UI_pysat  import Ui_MainWindow
 from traj_satellite  import Trajectoire
@@ -37,11 +38,11 @@ from point import Point
 from matplotlib_widget import MyMplCanvas
 from repertoire import repertoire
 from video import Cinema
-import flottant
+import flottant as flottant
 from debug import Debug
 
-class StartQT4(QMainWindow):
-    def __init__(self, parent, rep=None , debugger=Debug(0), app=None):
+class StartQT5(QMainWindow):
+    def __init__(self, parent, rep=None , debugger=Debug(1), app=None):
         QMainWindow.__init__(self)
         QWidget.__init__(self, parent)
         self.debug=debugger
@@ -54,8 +55,8 @@ class StartQT4(QMainWindow):
             self.rep=rep
         self.trajectoire = Trajectoire(self.ui.afficheur, 6400, self, debugger=self.debug)
         self.initAstres()
-        self.ui.masse_astre.setText(QApplication.translate("MainWindow", "6x10^24", None, QApplication.UnicodeUTF8))
-        self.ui.rayon_astre.setText(QApplication.translate("MainWindow", "6400", None, QApplication.UnicodeUTF8))
+        self.ui.masse_astre.setText("6x10^24")
+        self.ui.rayon_astre.setText("6400")
         os.chdir(self.rep.chemin("defaut"))
         self.image_sat=QPixmap("icones/sat_mini.gif")
         self.connexions_signaux()
@@ -87,22 +88,21 @@ class StartQT4(QMainWindow):
         Peuple le combo avec les noms d'astres
         """
         for a in astreNom:
-            self.ui.astreCombo.addItem(QApplication.translate("MainWindow", a[0], None, QApplication.UnicodeUTF8))
+            self.ui.astreCombo.addItem(self.tr(a[0]))
         self.ui.astreCombo.setEditable(False)
         self.ui.astreCombo.setCurrentIndex(0)
         self.astreCourant="earth"
         self.choisi_astre(0)
         
     def connexions_signaux(self):
-        QObject.connect(self.ui.Bouton_Lancer,SIGNAL("clicked()"), self.trajectoire.lance)
-        QObject.connect(self.ui.Button_efface,SIGNAL("clicked()"), self.efface_trajectoire)
-        QObject.connect(self.ui.bouton_video,SIGNAL("clicked()"), self.cinema)
-        QObject.connect(self.ui.altitude_objet,SIGNAL("editingFinished()"), self.placeDepart)
-        QObject.connect(self.ui.astreCombo,SIGNAL("currentIndexChanged(int)"),self.choisi_astre)
-        QObject.connect(self.ui.radioButton_Frenet,SIGNAL("toggled(bool)"), self.choisi_coordoonees)
-        #QObject.connect(self.ui.checkBox_efface,SIGNAL("stateChanged(bool)"), self.change_comportement_effacege)
+        self.ui.Bouton_Lancer.clicked.connect(self.trajectoire.lance)
+        self.ui.Button_efface.clicked.connect(self.efface_trajectoire)
+        self.ui.bouton_video.clicked.connect(self.cinema)
+        self.ui.altitude_objet.editingFinished.connect(self.placeDepart)
+        self.ui.astreCombo.currentIndexChanged.connect(self.choisi_astre)
+        self.ui.radioButton_Frenet.toggled.connect(self.choisi_coordoonees)
         timer = QTimer(self);
-        QObject.connect(timer, SIGNAL("timeout()"), self.routines);
+        timer.timeout.connect(self.routines);
         timer.start(1000);
 
 
@@ -127,9 +127,9 @@ class StartQT4(QMainWindow):
         if self.trajectoire.traj != None:
             liste_temps=arange(0,self.trajectoire.t,self.trajectoire.dt)
             pas=10 # une image pour 10 calculs numériques
-            titre=QApplication.translate("MainWindow", "Calcul de la vidéo", None, QApplication.UnicodeUTF8)
-            legende=QApplication.translate("MainWindow", "Avancement ...", None, QApplication.UnicodeUTF8)
-            echap=QApplication.translate("MainWindow", "Arrêt", None, QApplication.UnicodeUTF8)
+            titre=self.tr("Calcul de la vidéo")
+            legende=self.tr("Avancement ...")
+            echap=self.tr("Arrêt")
             self.progress=QProgressDialog(legende,echap,0,len(liste_temps)/pas)
             self.progress.setWindowTitle(titre)
             self.progress.setValue(0)
@@ -166,12 +166,12 @@ class StartQT4(QMainWindow):
         
     def choisi_coordoonees(self,bool):
         if self.ui.radioButton_Cartesiennes.isChecked()==True :
-            self.ui.label_V1.setText(QApplication.translate("MainWindow", "Vitesse selon Ox", None, QApplication.UnicodeUTF8))
-            self.ui.label_V2.setText(QApplication.translate("MainWindow", "Vitesse selon Oy", None, QApplication.UnicodeUTF8))
+            self.ui.label_V1.setText(self.tr("Vitesse selon Ox"))
+            self.ui.label_V2.setText(self.tr("Vitesse selon Oy"))
             
         elif self.ui.radioButton_Cartesiennes.isChecked()==False :
-            self.ui.label_V1.setText(QApplication.translate("MainWindow", "Vitesse Tangentielle", None, QApplication.UnicodeUTF8))
-            self.ui.label_V2.setText(QApplication.translate("MainWindow", "Vitesse Normale", None, QApplication.UnicodeUTF8))
+            self.ui.label_V1.setText(self.tr("Vitesse Tangentielle"))
+            self.ui.label_V2.setText(self.tr("Vitesse Normale"))
 
 
     def choisi_astre(self,int):
@@ -189,15 +189,15 @@ class StartQT4(QMainWindow):
                 self.astreCourant=a[1]
                 masse_astre=a[2]
                 rayon_astre=a[3]
-                self.ui.masse_astre.setText(QApplication.translate("MainWindow", masse_astre, None, QApplication.UnicodeUTF8))
-                self.ui.rayon_astre.setText(QApplication.translate("MainWindow", rayon_astre, None, QApplication.UnicodeUTF8))
+                self.ui.masse_astre.setText(self.tr(masse_astre))
+                self.ui.rayon_astre.setText(self.tr(rayon_astre))
                 mt=flottant.traduit(masse_astre)/flottant.traduit(mt0)
                 rt=flottant.traduit(rayon_astre)/flottant.traduit(rt0)
                 mt="%5g" %mt
                 rt="%5g" %rt
-                self.ui.mTerre.setText(QApplication.translate("MainWindow", mt, None, QApplication.UnicodeUTF8))
-                self.ui.rTerre.setText(QApplication.translate("MainWindow", rt, None, QApplication.UnicodeUTF8))
-                self.ui.auSujetAstre.setText(QApplication.translate("MainWindow", a[4], None, QApplication.UnicodeUTF8))
+                self.ui.mTerre.setText(self.tr(mt))
+                self.ui.rTerre.setText(self.tr(rt))
+                self.ui.auSujetAstre.setText(self.tr(a[4]))
                 self.placeDepart()
                 self.trajectoire.update()
                 return
