@@ -7,12 +7,13 @@
 
 from numpy import *
 from pylab import *
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt5.QtGui import *
+from PyQt5.QtWidgets import *
+from PyQt5.QtCore import *
 from point import Point
 import os, tempfile, time
 from matplotlib_widget import MyMplCanvas
-import flottant
+import flottant as flottant
 from rectangle_sensible import Rs
 from debug import Debug
 
@@ -240,10 +241,10 @@ class Trajectoire(Rs):
         Em_massique=Ec_massique+Ep_massique
         if Em_massique >= 0:
             self.debug(1,"L'énergie mécanique est excessive (%s J/kg), la trajectoire ne se fermera pas" %Em_massique)
-            t=QApplication.translate("MainWindow", "Ce n'est pas un satellite", None, QApplication.UnicodeUTF8)
-            q=QApplication.translate("MainWindow", "L'énergie mécanique initiale est positive, l'objet lancé échappera à l'attraction de l'astre. Voulez-vous tracer une partie de la trajectoire ?", None, QApplication.UnicodeUTF8)
-            ret=QMessageBox.question (self, t, q, 1, 2)
-            if ret==1:
+            t=self.tr("Ce n'est pas un satellite")
+            q=self.tr("L'énergie mécanique initiale est positive, l'objet lancé échappera à l'attraction de l'astre. Voulez-vous tracer une partie de la trajectoire ?")
+            ret=QMessageBox.question (self, t, q)
+            if ret==QMessageBox.Yes:
                 self.t=30*(self.distance_astre**3/self.masse_astre/self.G)**0.5
                 self.dt=self.t/100
             else:
@@ -270,10 +271,10 @@ class Trajectoire(Rs):
         # on teste si toute la trajectoire tien bien là.
         r=self.maxDistance(self.traj.pv)
         if not self.surementVisible(r) and not self.boum > 0:
-            t=QApplication.translate("MainWindow", "Changement d'échelle", None, QApplication.UnicodeUTF8)
-            q=QApplication.translate("MainWindow", "Un dépassement a été détecté. Voulez-vous changer d'échelle ?", None, QApplication.UnicodeUTF8)
-            ret=QMessageBox.question (self, t, q, 1, 2)
-            if ret==1:
+            t=self.tr("Changement d'échelle")
+            q=self.tr("Un dépassement a été détecté. Voulez-vous changer d'échelle ?")
+            ret=QMessageBox.question (self, t, q)
+            if ret==QMessageBox.Yes:
                 self.setEchelle(r,"max")
                 self.efface()
                 self.dessine(self.traj.pv)
