@@ -7,10 +7,11 @@ tableau de positions-vitesses tel que pysatellite peut le réaliser.
 
 import math, datetime, tempfile, os.path, os
 from astres import Astre
-from PyQt4.QtGui import *
+from PyQt5.QtGui import *
+from PyQt5.QtWidgets import *
 from threading import *
 from debug import Debug
-import flottant
+import flottant as flottant
 
 class Cinema(Thread):
     def __init__(self,repertoire, astre, dateorigine, liste_temps, liste_pos, geometrie, pas=1, nettoie=True, boum=-1.0, debugger=Debug(0)):
@@ -36,7 +37,7 @@ class Cinema(Thread):
         
     def video(self):
         self.images()
-        cmd="avconv -r 25 -f image2 -i %s -r 25 -f avi -vcodec mpeg1video -b 800k %s > /dev/null 2>&1" %(os.path.join(self.dir, "%04d.jpg"), os.path.join(self.dir, "out.avi"))
+        cmd="ffmpeg -r 25 -f image2 -i %s -f avi -vcodec mpeg1video -b 800k %s > /dev/null 2>&1" %(os.path.join(self.dir, "%04d.jpg"), os.path.join(self.dir, "out.avi"))
         os.system(cmd)
 
     def images(self):
